# -*- coding: utf-8 -*-
#
# Cookbook Name:: pentestenv
# Recipe:: default
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

execute "bundle-#{node['pentestenv']['install_dir']}" do
  action :nothing
  user node['pentestenv']['user']
  group 'root'
  cwd node['pentestenv']['install_dir']
  command 'bundle install --path vendor/bundle'
  only_if 'which bundle'
end

execute "berks-#{node['pentestenv']['install_dir']}" do
  action :nothing
  user node['pentestenv']['user']
  group 'root'
  cwd node['pentestenv']['install_dir']
  command 'bundle exec berks vendor cookbooks'
  environment 'BERKSHELF_PATH' => './.berkshelf'
  only_if 'which bundle'
end

directory node['pentestenv']['install_dir'] do
  owner node['pentestenv']['user']
  group 'root'
end

git node['pentestenv']['install_dir'] do
  user node['pentestenv']['user']
  group 'root'
  repository node['pentestenv']['repository']
  reference node['pentestenv']['reference']
  enable_submodules true
  action :sync
  notifies :run, "execute[bundle-#{node['pentestenv']['install_dir']}]", :delayed
  notifies :run, "execute[berks-#{node['pentestenv']['install_dir']}]", :delayed
end

link node['pentestenv']['bin_script'] do
  owner node['pentestenv']['user']
  group 'root'
  link_type :symbolic
  to "#{node['pentestenv']['install_dir']}/bin/pentest-env"
end

node['pentestenv']['resources'].each do |path, conf|
  pentestenv_rc path do
    owner node['pentestenv']['user']
    group 'root'
    cookbook 'pentestenv'
    source 'rc.erb'
    mode '0644'
    config conf
  end
end
